@@ -1,13 +1,13 @@
 package IO::Async::Loop::Epoll::FD;
-$IO::Async::Loop::Epoll::FD::VERSION = '0.002';
+$IO::Async::Loop::Epoll::FD::VERSION = '0.003';
 use strict;
 use warnings;
 
 use parent 'IO::Async::Loop::Epoll';
 
 use Carp 'croak';
-use Linux::FD qw/timerfd signalfd/;
-use Linux::FD::Pid;
+use Linux::FD 0.015 qw/timerfd signalfd/;
+use Linux::FD::Pid 0.007;
 use Scalar::Util qw/refaddr weaken/;
 use Signal::Mask;
 
@@ -52,25 +52,27 @@ sub unwatch_signal {
 }
 
 sub post_fork {
-   my $self = shift;
+	my $self = shift;
 
-   $self->{epoll} = Linux::Epoll->new;
-   $self->{pid} = $$;
+	$self->{epoll} = Linux::Epoll->new;
+	$self->{pid} = $$;
 
-   my $watches = $self->{iowatches} or return;
+	my $watches = $self->{iowatches} or return;
+	my $fakeevents = $self->{fakeevents};
 
-   foreach my $watch ( values %$watches ) {
-      my ( $handle, $on_read_ready, $on_write_ready, $on_hangup ) = @$watch;
-      my $fd = $handle->fileno;
-      my $mask = $self->{masks}->{$fd};
-      my @bits;
-      push @bits, 'in'  if $mask & IO::Async::Loop::Epoll::WATCH_READ;
-      push @bits, 'out' if $mask & IO::Async::Loop::Epoll::WATCH_WRITE;
-      push @bits, 'hup' if $mask & IO::Async::Loop::Epoll::WATCH_HUP;
-      my $cb = $self->{callbacks}->{$fd};
+	foreach my $watch ( values %$watches ) {
+		my ($handle) = @$watch;
+		my $fd = $handle->fileno;
+		next if $fakeevents->{$fd};
+		my $mask = $self->{masks}->{$fd};
+		my @bits;
+		push @bits, 'in'  if $mask & IO::Async::Loop::Epoll::WATCH_READ;
+		push @bits, 'out' if $mask & IO::Async::Loop::Epoll::WATCH_WRITE;
+		push @bits, 'hup' if $mask & IO::Async::Loop::Epoll::WATCH_HUP;
+		my $cb = $self->{callbacks}->{$fd};
 
-      $self->{epoll}->add($handle, \@bits, $cb);
-   }
+		$self->{epoll}->add($handle, \@bits, $cb);
+	}
 }
 
 sub watch_time {
@@ -166,7 +168,7 @@ IO::Async::Loop::Epoll::FD - Use IO::Async with Epoll and special filehandles
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
